<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Object</name>
    <message>
        <source>Duplicate method name</source>
        <translation>Powielona nazwa metody</translation>
    </message>
    <message>
        <source>Method names cannot begin with an upper case letter</source>
        <translation>Nazwy metod nie mogą rozpoczynać się wielką literą</translation>
    </message>
    <message>
        <source>Illegal method name</source>
        <translation>Niepoprawna nazwa metody</translation>
    </message>
    <message>
        <source>Duplicate signal name</source>
        <translation>Powielona nazwa sygnału</translation>
    </message>
    <message>
        <source>Duplicate property name</source>
        <translation>Powielona nazwa właściwości</translation>
    </message>
    <message>
        <source>Property names cannot begin with an upper case letter</source>
        <translation>Nazwy właściwości nie mogą rozpoczynać się wielką literą</translation>
    </message>
    <message>
        <source>Duplicate default property</source>
        <translation>Powielona domyślna właściwość</translation>
    </message>
    <message>
        <source>Property value set multiple times</source>
        <translation>Wartość właściwości ustawiona wielokrotnie</translation>
    </message>
</context>
<context>
    <name>QInputMethod</name>
    <message>
        <source>InputMethod is an abstract class</source>
        <translation>&quot;InputMethod&quot; jest klasą abstrakcyjną</translation>
    </message>
</context>
<context>
    <name>QQmlAnonymousComponentResolver</name>
    <message>
        <source>Component objects cannot declare new functions.</source>
        <translation>Instancje komponentu nie mogą deklarować nowych funkcji.</translation>
    </message>
    <message>
        <source>Component objects cannot declare new properties.</source>
        <translation>Instancje komponentu nie mogą deklarować nowych właściwości.</translation>
    </message>
    <message>
        <source>Component objects cannot declare new signals.</source>
        <translation>Instancje komponentu nie mogą deklarować nowych sygnałów.</translation>
    </message>
    <message>
        <source>Cannot create empty component specification</source>
        <translation>Nie można utworzyć pustej specyfikacji komponentu</translation>
    </message>
    <message>
        <source>Component elements may not contain properties other than id</source>
        <translation>Elementy komponentu nie mogą posiadać właściwości innych niż &quot;id&quot;</translation>
    </message>
    <message>
        <source>Invalid component body specification</source>
        <translation>Niepoprawna specyfikacja &quot;body&quot; komponentu</translation>
    </message>
    <message>
        <source>id is not unique</source>
        <translation>Wartość &quot;id&quot; nie jest unikatowa</translation>
    </message>
    <message>
        <source>Invalid alias reference. Unable to find id &quot;%1&quot;</source>
        <translation>Niepoprawna referencja aliasu. Nie można odnaleźć identyfikatora &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Invalid alias target location: %1</source>
        <translation>Niepoprane położenie docelowe aliasu: %1</translation>
    </message>
</context>
<context>
    <name>QQmlCodeGenerator</name>
    <message>
        <source>Property value set multiple times</source>
        <translation>Wartość właściwości ustawiona wielokrotnie</translation>
    </message>
    <message>
        <source>Expected type name</source>
        <translation>Oczekiwana nazwa typu</translation>
    </message>
    <message>
        <source>Signal names cannot begin with an upper case letter</source>
        <translation>Nazwy sygnałów nie mogą rozpoczynać się wielką literą</translation>
    </message>
    <message>
        <source>Illegal signal name</source>
        <translation>Niepoprawna nazwa sygnału</translation>
    </message>
    <message>
        <source>No property alias location</source>
        <translation>Niepoprawne położenie właściwości aliasu</translation>
    </message>
    <message>
        <source>Invalid alias reference. An alias reference must be specified as &lt;id&gt;, &lt;id&gt;.&lt;property&gt; or &lt;id&gt;.&lt;value property&gt;.&lt;property&gt;</source>
        <translation>Niepoprawna referencja aliasu. Referencja aliasu musi być podana jako &lt;id&gt;, &lt;id&gt;.&lt;property&gt; lub &lt;id&gt;.&lt;value property&gt;.&lt;property&gt;</translation>
    </message>
    <message>
        <source>Invalid alias location</source>
        <translation>Niepoprawne położenie aliasu</translation>
    </message>
    <message>
        <source>Illegal property name</source>
        <translation>Niepoprawna nazwa właściwości</translation>
    </message>
    <message>
        <source>Invalid component id specification</source>
        <translation>Niepoprawna specyfikacja &quot;id&quot; komponentu</translation>
    </message>
    <message>
        <source>Invalid empty ID</source>
        <translation>Niepoprawny pusty identyfikator</translation>
    </message>
    <message>
        <source>IDs cannot start with an uppercase letter</source>
        <translation>Identyfikatory nie mogą rozpoczynać się wielką literą</translation>
    </message>
    <message>
        <source>IDs must start with a letter or underscore</source>
        <translation>Identyfikatory muszą rozpoczynać się literą lub znakiem podkreślenia</translation>
    </message>
    <message>
        <source>IDs must contain only letters, numbers, and underscores</source>
        <translation>Identyfikatory mogą zawierać jedynie litery, cyfry i znaki podkreślenia</translation>
    </message>
    <message>
        <source>ID illegally masks global JavaScript property</source>
        <translation>Identyfikator nielegalnie maskuje globalną właściwość JavaScript</translation>
    </message>
    <message>
        <source>Invalid use of id property</source>
        <translation>Niepoprawne użycie właściwości &quot;id&quot;</translation>
    </message>
</context>
<context>
    <name>QQmlComponent</name>
    <message>
        <source>Invalid empty URL</source>
        <translation>Niepoprawny pusty URL</translation>
    </message>
    <message>
        <source>createObject: value is not an object</source>
        <translation>&quot;createObject&quot;: wartość nie jest obiektem</translation>
    </message>
    <message>
        <source>Object destroyed during incubation</source>
        <translation>Obiekt zniszczony podczas konstrukcji</translation>
    </message>
</context>
<context>
    <name>QQmlConnections</name>
    <message>
        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
        <translation>Nie można przypisać wartości do nieistniejącej właściwości &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Connections: nested objects not allowed</source>
        <translation>Połączenia: zagnieżdżone obiekty nie są dozwolone</translation>
    </message>
    <message>
        <source>Connections: syntax error</source>
        <translation>Połączenia: błąd składni</translation>
    </message>
    <message>
        <source>Connections: script expected</source>
        <translation>Połączenia: oczekiwano skryptu</translation>
    </message>
</context>
<context>
    <name>QQmlDebugServerImpl</name>
    <message>
        <source>QML Debugger: Invalid argument &quot;%1&quot; detected. Ignoring the same.</source>
        <translation>Debugger QML: wykryto niepoprawny argument &quot;%1&quot;, zostanie on zignorowany.</translation>
    </message>
    <message>
        <source>QML Debugger: Ignoring &quot;-qmljsdebugger=%1&quot;.</source>
        <translation>Debugger QML: &quot;-qmljsdebugger=%1&quot; zostanie zignorowane.</translation>
    </message>
    <message>
        <source>The format is &quot;-qmljsdebugger=[file:&lt;file&gt;|port:&lt;port_from&gt;][,&lt;port_to&gt;][,host:&lt;ip address&gt;][,block][,services:&lt;service&gt;][,&lt;service&gt;]*&quot;</source>
        <translation>Formatem jest &quot;-qmljsdebugger=[file:&lt;plik&gt;|port:&lt;z portu&gt;][,&lt;do portu&gt;][,host:&lt;adres ip&gt;][,block][,services:&lt;serwis&gt;][,&lt;service&gt;]*&quot;</translation>
    </message>
    <message>
        <source>&quot;file:&quot; can be used to specify the name of a file the debugger will try to connect to using a QLocalSocket. If &quot;file:&quot; is given any &quot;host:&quot; and&quot;port:&quot; arguments will be ignored.</source>
        <translation>&quot;file:&quot; służy do podania nazwy pliku, do którego debugger będzie próbował się podłączyć używając QLocalSocket. Jeśli wraz z &quot;file:&quot; podano również &quot;host:&quot; lub &quot;port:&quot;, argumenty te zostaną zignorowane.</translation>
    </message>
    <message>
        <source>&quot;host:&quot; and &quot;port:&quot; can be used to specify an address and a single port or a range of ports the debugger will try to bind to with a QTcpServer.</source>
        <translation>&quot;host:&quot; i &quot;port:&quot; służą do podania adresu i pojedynczego portu lub zakresu portów, przez które debugger będzie próbował nawiązać połączenie przy użyciu QTcpServer.</translation>
    </message>
    <message>
        <source>&quot;block&quot; makes the debugger and some services wait for clients to be connected and ready before the first QML engine starts.</source>
        <translation>&quot;block&quot; nakazuje debuggerowi i niektórym serwisom oczekiwanie na połączenie i gotowość klientów przed pierwszym uruchomieniem silnika QML.</translation>
    </message>
    <message>
        <source>&quot;services:&quot; can be used to specify which debug services the debugger should load. Some debug services interact badly with others. The V4 debugger should not be loaded when using the QML profiler as it will force any V4 engines to use the JavaScript interpreter rather than the JIT. The following debug services are available by default:</source>
        <translation>&quot;services:&quot; służą do podania nazw serwisów, które debugger powinien załadować. Niektóre serwisy nie współdziałają dobrze ze sobą. Debugger V4 nie powinien być załadowany kiedy używany jest profiler QML, ponieważ zmusza on wszystkie silniki V4 do używania interpretera JavaScript zamiast JIT. Następujące serwisy są domyślnie dostępne:</translation>
    </message>
    <message>
        <source>The QML debugger</source>
        <translation>Debugger QML</translation>
    </message>
    <message>
        <source>The V4 debugger</source>
        <translation>Debugger V4</translation>
    </message>
    <message>
        <source>The QML inspector</source>
        <translation>Inspektor QML</translation>
    </message>
    <message>
        <source>The QML profiler</source>
        <translation>Profiler QML</translation>
    </message>
    <message>
        <source>Allows the client to delay the starting and stopping of
		  QML engines until other services are ready. QtCreator
		  uses this service with the QML profiler in order to
		  profile multiple QML engines at the same time.</source>
        <translation>Pozwala klientom na opóźnione uruchomienie bądź zatrzymanie
		  silników QML do momentu gdy inne serwisy są gotowe. QtCreator
		  używa tego serwisu do profilowania wielu silników QML jednocześnie.</translation>
    </message>
    <message>
        <source>Sends qDebug() and similar messages over the QML debug
		  connection. QtCreator uses this for showing debug
		  messages in the debugger console.</source>
        <translation>Wysyła komunikaty qDebug() i podobne przez połączenie debugowe QML.
		  QtCreator używa go do pokazywania komunikatów
		  debugowych w konsoli debuggera.</translation>
    </message>
    <message>
        <source>Other services offered by qmltooling plugins that implement QQmlDebugServiceFactory and which can be found in the standard plugin paths will also be available and can be specified. If no &quot;services&quot; argument is given, all services found this way, including the default ones, are loaded.</source>
        <translation>Inne serwisy, dostępne we wtyczkach qmltooling, które implementują QQmlDebugServiceFactory i które mogą być odnalezione w standardowych ścieżkach do wtyczek, również mogą zostać podane. Jeśli nie podano argumentu &quot;services&quot;, wszystkie serwisy odnalezione w ten sposób, włącznie z domyślnymi, zostaną załadowane.</translation>
    </message>
</context>
<context>
    <name>QQmlDelegateModel</name>
    <message>
        <source>The delegate of a DelegateModel cannot be changed within onUpdated.</source>
        <translation>Delegat &quot;DelegateModel&quot; nie może być zmieniany podczas &quot;onUpdated&quot;.</translation>
    </message>
    <message>
        <source>The maximum number of supported DelegateModelGroups is 8</source>
        <translation>Maksymalna liczba obsługiwanych &quot;DelegateModelGroups&quot; to 8</translation>
    </message>
    <message>
        <source>The group of a DelegateModel cannot be changed within onChanged</source>
        <translation>Grupa &quot;DelegateModel&quot; nie może być zmieniana podczas &quot;onChanged&quot;</translation>
    </message>
</context>
<context>
    <name>QQmlDelegateModelGroup</name>
    <message>
        <source>Group names must start with a lower case letter</source>
        <translation>Nazwy grup muszą rozpoczynać się wielką literą</translation>
    </message>
    <message>
        <source>get: index out of range</source>
        <translation>get: indeks poza zakresem</translation>
    </message>
    <message>
        <source>insert: index out of range</source>
        <translation>insert: indeks poza zakresem</translation>
    </message>
    <message>
        <source>create: index out of range</source>
        <translation>create: indeks poza zakresem</translation>
    </message>
    <message>
        <source>resolve: from index out of range</source>
        <translation>resolve: indeks początkowy poza zakresem</translation>
    </message>
    <message>
        <source>resolve: from index invalid</source>
        <translation>resolve: niepoprawny indeks początkowy</translation>
    </message>
    <message>
        <source>resolve: to index out of range</source>
        <translation>resolve: indeks końcowy poza zakresem</translation>
    </message>
    <message>
        <source>resolve: to index invalid</source>
        <translation>resolve: niepoprawny indeks końcowy</translation>
    </message>
    <message>
        <source>resolve: from is not an unresolved item</source>
        <translation>resolve: początek nie jest nierozwiązanym elementem</translation>
    </message>
    <message>
        <source>resolve: to is not a model item</source>
        <translation>resolve: koniec nie jest elementem modelu</translation>
    </message>
    <message>
        <source>remove: invalid index</source>
        <translation>remove: niepoprawny indeks</translation>
    </message>
    <message>
        <source>remove: index out of range</source>
        <translation>remove: indeks poza zakresem</translation>
    </message>
    <message>
        <source>remove: invalid count</source>
        <translation>remove: niepoprawna ilość</translation>
    </message>
    <message>
        <source>addGroups: index out of range</source>
        <translation>addGroups: indeks poza zakresem</translation>
    </message>
    <message>
        <source>addGroups: invalid count</source>
        <translation>addGroups: niepoprawna ilość</translation>
    </message>
    <message>
        <source>removeGroups: index out of range</source>
        <translation>removeGroups: indeks poza zakresem</translation>
    </message>
    <message>
        <source>removeGroups: invalid count</source>
        <translation>removeGroups: niepoprawna ilość</translation>
    </message>
    <message>
        <source>setGroups: index out of range</source>
        <translation>setGroups: indeks poza zakresem</translation>
    </message>
    <message>
        <source>setGroups: invalid count</source>
        <translation>setGroups: niepoprawna ilość</translation>
    </message>
    <message>
        <source>move: invalid from index</source>
        <translation>move: niepoprawny indeks początkowy</translation>
    </message>
    <message>
        <source>move: invalid to index</source>
        <translation>move: niepoprawny indeks końcowy</translation>
    </message>
    <message>
        <source>move: invalid count</source>
        <translation>move: niepoprawna ilość</translation>
    </message>
    <message>
        <source>move: from index out of range</source>
        <translation>move: indeks początkowy poza zakresem</translation>
    </message>
    <message>
        <source>move: to index out of range</source>
        <translation>move: indeks końcowy poza zakresem</translation>
    </message>
</context>
<context>
    <name>QQmlEngine</name>
    <message>
        <source>Locale cannot be instantiated.  Use Qt.locale()</source>
        <translation>Nie można zinstancjonować obiektu klasy Locale. Użyj Qt.locale()</translation>
    </message>
    <message>
        <source>There are still &quot;%1&quot; items in the process of being created at engine destruction.</source>
        <translation>Elementy &quot;%1&quot; są wciąż konstruowane w trakcie niszczenia silnika.</translation>
    </message>
    <message>
        <source>executeSql called outside transaction()</source>
        <translation>&quot;executeSql&quot; wywołane na zewnątrz &quot;transation()&quot;</translation>
    </message>
    <message>
        <source>Read-only Transaction</source>
        <translation>Transakcja tylko do odczytu</translation>
    </message>
    <message>
        <source>Version mismatch: expected %1, found %2</source>
        <translation>Niezgodność wersji: oczekiwano %1, znaleziono %2</translation>
    </message>
    <message>
        <source>SQL transaction failed</source>
        <translation>Transakcja SQL zakończona błędem</translation>
    </message>
    <message>
        <source>transaction: missing callback</source>
        <translation>transakcja: brak wywołania zwrotnego</translation>
    </message>
    <message>
        <source>SQL: can&apos;t create database, offline storage is disabled.</source>
        <translation>SQL: nie można utworzyć bazy danych, praca offline jest wyłączona.</translation>
    </message>
    <message>
        <source>SQL: database version mismatch</source>
        <translation>SQL: niezgodność wersji bazy danych</translation>
    </message>
</context>
<context>
    <name>QQmlEnumTypeResolver</name>
    <message>
        <source>Invalid property assignment: Enum value &quot;%1&quot; cannot start with a lowercase letter</source>
        <translation>Niepoprawne przypisanie wartości: wartość typu wyliczeniowego &quot;%1&quot; nie może rozpoczynać się od małej litery</translation>
    </message>
    <message>
        <source>Invalid property assignment: &quot;%1&quot; is a read-only property</source>
        <translation>Niepoprawne przypisanie wartości: &quot;%1&quot; jest właściwością tylko do odczytu</translation>
    </message>
</context>
<context>
    <name>QQmlImportDatabase</name>
    <message>
        <source>&quot;%1&quot; is ambiguous. Found in %2 and in %3</source>
        <translation>&quot;%1&quot; jest niejednoznaczny. Znaleziono w %2 i w %3</translation>
    </message>
    <message>
        <source>- %1 is not a namespace</source>
        <translation>- %1 nie jest przestrzenią nazw</translation>
    </message>
    <message>
        <source>- nested namespaces not allowed</source>
        <translation>- zagnieżdżone przestrzenie nazw są niedozwolone</translation>
    </message>
    <message>
        <source>local directory</source>
        <translation>lokalny katalog</translation>
    </message>
    <message>
        <source>is ambiguous. Found in %1 and in %2</source>
        <translation>jest niejednoznaczny. Znaleziono w %1 i w %2</translation>
    </message>
    <message>
        <source>is ambiguous. Found in %1 in version %2.%3 and %4.%5</source>
        <translation>jest niejednoznaczny. Znaleziono w %1 w wersji %2.%3 i %4.%5</translation>
    </message>
    <message>
        <source>is instantiated recursively</source>
        <translation>jest zinstancjonowany rekurencyjnie</translation>
    </message>
    <message>
        <source>is not a type</source>
        <translation>nie jest typem</translation>
    </message>
    <message>
        <source>static plugin for module &quot;%1&quot; with name &quot;%2&quot; has no metadata URI</source>
        <translation>brak metadata URI w statycznej wtyczce &quot;%2&quot; w module &quot;%1&quot;</translation>
    </message>
    <message>
        <source>module does not support the designer &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>plugin cannot be loaded for module &quot;%1&quot;: %2</source>
        <translation>wtyczka nie może zostać załadowana dla modułu &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <source>static plugin for module &quot;%1&quot; with name &quot;%2&quot; cannot be loaded: %3</source>
        <translation>statyczna wtyczka dla modułu &quot;%1&quot; o nazwie &quot;%2&quot; nie może zostać załadowana: %3</translation>
    </message>
    <message>
        <source>could not resolve all plugins for module &quot;%1&quot;</source>
        <translation>nie można rozwiązać wszystkich wtyczek w module &quot;%1&quot;</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; plugin &quot;%2&quot; not found</source>
        <translation>wtyczka &quot;%2&quot; modułu &quot;%1&quot; nie została odnaleziona</translation>
    </message>
    <message>
        <source>library loading is disabled</source>
        <translation>ładowanie bibliotek wyłączone</translation>
    </message>
    <message>
        <source>&quot;%1&quot; version %2.%3 is defined more than once in module &quot;%4&quot;</source>
        <translation>&quot;%1&quot; wersji %2.%3 jest zdefiniowany wielokrotnie w module &quot;%4&quot;</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; version %2.%3 is not installed</source>
        <translation>wersja %2.%3 modułu %1 nie jest zainstalowana</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; is not installed</source>
        <translation>moduł &quot;%1&quot; nie jest zainstalowany</translation>
    </message>
    <message>
        <source>&quot;%1&quot;: no such directory</source>
        <translation>&quot;%1&quot;: brak katalogu</translation>
    </message>
    <message>
        <source>import &quot;%1&quot; has no qmldir and no namespace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Module loaded for URI &apos;%1&apos; does not implement QQmlTypesExtensionInterface</source>
        <translation>Moduł załadowany dla URI &quot;%1&quot; nie implementuje QQmlTypesExtensionInterface</translation>
    </message>
    <message>
        <source>Module namespace &apos;%1&apos; does not match import URI &apos;%2&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Namespace &apos;%1&apos; has already been used for type registration</source>
        <translation>Przestrzeń nazw &quot;%1&quot; została już użyta do rejestracji typu</translation>
    </message>
    <message>
        <source>Module &apos;%1&apos; does not contain a module identifier directive - it cannot be protected from external registrations.</source>
        <translation>Moduł &quot;%1&quot; nie zawiera dyrektywy identyfikującej moduł - nie może być on zabezpieczony przed zewnętrznym zarejestrowaniem.</translation>
    </message>
    <message>
        <source>File name case mismatch for &quot;%1&quot;</source>
        <translation>Niezgodność wielkości liter w nazwie pliku &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>QQmlListModel</name>
    <message>
        <source>unable to enable dynamic roles as this model is not empty!</source>
        <translation>nie można włączyć dynamicznych roli ponieważ ten model nie jest pusty.</translation>
    </message>
    <message>
        <source>unable to enable static roles as this model is not empty!</source>
        <translation>nie można włączyć statycznych roli ponieważ ten model nie jest pusty.</translation>
    </message>
    <message>
        <source>dynamic role setting must be made from the main thread, before any worker scripts are created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>remove: indices [%1 - %2] out of range [0 - %3]</source>
        <translation>remove: indeksy [%1 - %2] poza zakresem [0 - %3]</translation>
    </message>
    <message>
        <source>remove: incorrect number of arguments</source>
        <translation>remove: niepoprawna liczba argumentów</translation>
    </message>
    <message>
        <source>insert: index %1 out of range</source>
        <translation>insert: indeks %1 poza zakresem</translation>
    </message>
    <message>
        <source>insert: value is not an object</source>
        <translation>insert: wartość nie jest obiektem</translation>
    </message>
    <message>
        <source>move: out of range</source>
        <translation>move: poza zakresem</translation>
    </message>
    <message>
        <source>append: value is not an object</source>
        <translation>append: wartość nie jest obiektem</translation>
    </message>
    <message>
        <source>set: value is not an object</source>
        <translation>set: wartość nie jest obiektem</translation>
    </message>
    <message>
        <source>set: index %1 out of range</source>
        <translation>set: indeks %1 poza zakresem</translation>
    </message>
    <message>
        <source>ListElement: cannot contain nested elements</source>
        <translation>ListElement: nie może zawierać zagnieżdżonych elementów</translation>
    </message>
    <message>
        <source>ListElement: cannot use reserved &quot;id&quot; property</source>
        <translation>ListElement: nie można używać zarezerwowanej właściwości &quot;id&quot;</translation>
    </message>
    <message>
        <source>ListElement: cannot use script for property value</source>
        <translation>ListElement: nie można używać skryptu jako wartości właściwości</translation>
    </message>
    <message>
        <source>ListModel: undefined property &apos;%1&apos;</source>
        <translation>ListModel: niezdefiniowana właściwość &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>QQmlObjectCreator</name>
    <message>
        <source>Cannot assign value %1 to property %2</source>
        <translation>Nie można przypisać wartości %1 do właściwości %2</translation>
    </message>
    <message>
        <source>Cannot set properties on %1 as it is null</source>
        <translation>Nie można ustawić właściwości dla %1 ponieważ jest on zerowy</translation>
    </message>
    <message>
        <source>Cannot assign an object to signal property %1</source>
        <translation>Nie można przypisać obiektu do właściwości sygnału %1</translation>
    </message>
    <message>
        <source>Cannot assign object type %1 with no default method</source>
        <translation>Nie można przypisać obiektu typu %1 który nie posiada domyślnej metody</translation>
    </message>
    <message>
        <source>Cannot connect mismatched signal/slot %1 %vs. %2</source>
        <translation>Nie można podłączyć niezgodnych sygnałów/slotów (%1 i %2)</translation>
    </message>
    <message>
        <source>Cannot assign object to interface property</source>
        <translation>Nie można przypisać obiektu do właściwości interfejsu</translation>
    </message>
    <message>
        <source>Cannot assign object to read only list</source>
        <translation>Nie można przypisać obiektu do listy przeznaczonej tylko do odczytu</translation>
    </message>
    <message>
        <source>Cannot assign primitives to lists</source>
        <translation>Nie można przypisać elementów prostych do listy</translation>
    </message>
    <message>
        <source>Unable to create object of type %1</source>
        <translation>Nie można utworzyć obiektu typu %1</translation>
    </message>
    <message>
        <source>Composite Singleton Type %1 is not creatable</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QQmlObjectModel</name>
    <message>
        <source>insert: index %1 out of range</source>
        <translation>insert: indeks %1 poza zakresem</translation>
    </message>
    <message>
        <source>move: out of range</source>
        <translation>move: poza zakresem</translation>
    </message>
    <message>
        <source>remove: indices [%1 - %2] out of range [0 - %3]</source>
        <translation>remove: indeksy [%1 - %2] poza zakresem [0 - %3]</translation>
    </message>
</context>
<context>
    <name>QQmlParser</name>
    <message>
        <source>Unexpected object definition</source>
        <translation>Nieoczekiwana definicja obiektu</translation>
    </message>
    <message>
        <source>Invalid import qualifier ID</source>
        <translation>Niepoprawny kwalifikator ID importu</translation>
    </message>
    <message>
        <source>Reserved name &quot;Qt&quot; cannot be used as an qualifier</source>
        <translation>&quot;Qt&quot; jest nazwą zarezerwowaną i nie może być użyta jako kwalifikator</translation>
    </message>
    <message>
        <source>Script import qualifiers must be unique.</source>
        <translation>Kwalifikator importu skryptu musi być unikatowy.</translation>
    </message>
    <message>
        <source>Script import requires a qualifier</source>
        <translation>Import skryptu wymaga użycia kwalifikatora</translation>
    </message>
    <message>
        <source>Library import requires a version</source>
        <translation>Import biblioteki wymaga podania wersji</translation>
    </message>
    <message>
        <source>Pragma requires a valid qualifier</source>
        <translation>Pragma wymaga poprawnego kwalifikatora</translation>
    </message>
    <message>
        <source>Expected parameter type</source>
        <translation>Oczekiwany typ parametru</translation>
    </message>
    <message>
        <source>Invalid signal parameter type: </source>
        <translation>Niepoprawny typ parametru sygnału:</translation>
    </message>
    <message>
        <source>Invalid property type modifier</source>
        <translation>Niepoprawny modyfikator typu właściwości</translation>
    </message>
    <message>
        <source>Unexpected property type modifier</source>
        <translation>Nieoczekiwany modyfikator typu właściwości</translation>
    </message>
    <message>
        <source>Expected property type</source>
        <translation>Oczekiwany typ właściwości</translation>
    </message>
    <message>
        <source>JavaScript declaration outside Script element</source>
        <translation>Deklaracja &quot;JavaScript&quot; na zewnątrz elementu &quot;Script&quot;</translation>
    </message>
    <message>
        <source>Illegal syntax for exponential number</source>
        <translation>Niepoprawna składnia liczby o postaci wykładniczej</translation>
    </message>
    <message>
        <source>Stray newline in string literal</source>
        <translation>Przypadkowy znak nowej linii w literale łańcuchowym</translation>
    </message>
    <message>
        <source>Illegal unicode escape sequence</source>
        <translation>Niepoprawny znak w sekwencji escape</translation>
    </message>
    <message>
        <source>Illegal hexadecimal escape sequence</source>
        <translation>Niepoprawna szesnastkowa sekwencja escape</translation>
    </message>
    <message>
        <source>Octal escape sequences are not allowed</source>
        <translation>Ósemkowe sekwencje escape są niedozwolone</translation>
    </message>
    <message>
        <source>Unclosed string at end of line</source>
        <translation>Niedomknięty ciąg na końcu linii</translation>
    </message>
    <message>
        <source>Decimal numbers can&apos;t start with &apos;0&apos;</source>
        <translation>Liczby dziesiętne nie mogą rozpoczynać się zerem</translation>
    </message>
    <message>
        <source>At least one hexadecimal digit is required after &apos;0%1&apos;</source>
        <translation>Wymagana jest przynajmniej jedna cyfra szesnastkowa następująca po &quot;0%1&quot;</translation>
    </message>
    <message>
        <source>Invalid regular expression flag &apos;%0&apos;</source>
        <translation>Niepoprawna flaga &quot;%0&quot; w wyrażeniu regularnym</translation>
    </message>
    <message>
        <source>Unterminated regular expression backslash sequence</source>
        <translation>Niedokończona sekwencja backslash wyrażenia regularnego</translation>
    </message>
    <message>
        <source>Unterminated regular expression class</source>
        <translation>Niedokończona klasa wyrażenia regularnego</translation>
    </message>
    <message>
        <source>Unterminated regular expression literal</source>
        <translation>Niedokończony literał wyrażenia regularnego</translation>
    </message>
    <message>
        <source>Syntax error</source>
        <translation>Błąd składni</translation>
    </message>
    <message>
        <source>Imported file must be a script</source>
        <translation>Zaimportowany plik musi być skryptem</translation>
    </message>
    <message>
        <source>Invalid module URI</source>
        <translation>Niepoprawny URI modułu</translation>
    </message>
    <message>
        <source>Module import requires a version</source>
        <translation>Import modułu wymaga podania wersji</translation>
    </message>
    <message>
        <source>File import requires a qualifier</source>
        <translation>Import pliku wymaga kwalifikatora</translation>
    </message>
    <message>
        <source>Module import requires a qualifier</source>
        <translation>Import modułu wymaga kwalifikatora</translation>
    </message>
    <message>
        <source>Invalid import qualifier</source>
        <translation>Niepoprawny kwalifikator importu</translation>
    </message>
    <message>
        <source>Unexpected token `%1&apos;</source>
        <translation>Nieoczekiwany znak &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Expected token `%1&apos;</source>
        <translation>Oczekiwany znak &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>QQmlPartsModel</name>
    <message>
        <source>The group of a DelegateModel cannot be changed within onChanged</source>
        <translation>Grupa &quot;DelegateModel&quot; nie może być zmieniana podczas &quot;onChanged&quot;</translation>
    </message>
    <message>
        <source>Delegate component must be Package type.</source>
        <translation>Komponent &quot;Delegate&quot; musi być typu &quot;Package&quot;.</translation>
    </message>
</context>
<context>
    <name>QQmlPropertyCacheCreator</name>
    <message>
        <source>Fully dynamic types cannot declare new properties.</source>
        <translation>Typy w pełni dynamiczne nie mogą deklarować nowych właściwości.</translation>
    </message>
    <message>
        <source>Fully dynamic types cannot declare new signals.</source>
        <translation>Typy w pełni dynamiczne nie mogą deklarować nowych sygnałów.</translation>
    </message>
    <message>
        <source>Fully Dynamic types cannot declare new functions.</source>
        <translation>Typy w pełni dynamiczne nie mogą deklarować nowych funkcji.</translation>
    </message>
    <message>
        <source>Non-existent attached object</source>
        <translation>Dołączony obiekt nie istnieje</translation>
    </message>
    <message>
        <source>Cannot override FINAL property</source>
        <translation>Nie można nadpisać właściwości &quot;FINAL&quot;</translation>
    </message>
    <message>
        <source>Invalid signal parameter type: %1</source>
        <translation>Niepoprawny typ parametru sygnału: %1</translation>
    </message>
    <message>
        <source>Duplicate signal name: invalid override of property change signal or superclass signal</source>
        <translation>Powielona nazwa sygnału: niepoprawne nadpisanie sygnału zmiany właściwości lub sygnału klasy bazowej</translation>
    </message>
    <message>
        <source>Duplicate method name: invalid override of property change signal or superclass signal</source>
        <translation>Powielona nazwa metody: niepoprawne nadpisanie sygnału zmiany właściwości lub sygnału klasy bazowej</translation>
    </message>
    <message>
        <source>Invalid property type</source>
        <translation>Niepoprawny typ właściwości</translation>
    </message>
</context>
<context>
    <name>QQmlPropertyValidator</name>
    <message>
        <source>Property assignment expected</source>
        <translation>Oczekiwano przypisania wartości</translation>
    </message>
    <message>
        <source>&quot;%1.%2&quot; is not available in %3 %4.%5.</source>
        <translation>&quot;%1.%2&quot; nie jest dostępne w %3 %4.%5.</translation>
    </message>
    <message>
        <source>&quot;%1.%2&quot; is not available due to component versioning.</source>
        <translation>&quot;%1.%2&quot; nie jest dostępne z powodu niekompatybilności wersji komponentu.</translation>
    </message>
    <message>
        <source>Cannot assign a value directly to a grouped property</source>
        <translation>Nie można bezpośrednio przypisać wartości do zgrupowanej właściwości</translation>
    </message>
    <message>
        <source>Invalid use of namespace</source>
        <translation>Niepoprawne użycie przestrzeni nazw</translation>
    </message>
    <message>
        <source>Invalid attached object assignment</source>
        <translation>Niepoprawne przypisanie dołączonego obiektu</translation>
    </message>
    <message>
        <source>Attached properties cannot be used here</source>
        <translation>Dołączone właściwości nie mogą być tutaj użyte</translation>
    </message>
    <message>
        <source>Invalid property assignment: &quot;%1&quot; is a read-only property</source>
        <translation>Niepoprawne przypisanie wartości: &quot;%1&quot; jest właściwością tylko do odczytu</translation>
    </message>
    <message>
        <source>Cannot assign multiple values to a script property</source>
        <translation>Nie można przypisać wielu wartości do skryptowej właściwości</translation>
    </message>
    <message>
        <source>Cannot assign multiple values to a singular property</source>
        <translation>Nie można przypisać wielu wartości do pojedynczej właściwości</translation>
    </message>
    <message>
        <source>Property has already been assigned a value</source>
        <translation>Wartość została już przypisana do właściwości</translation>
    </message>
    <message>
        <source>Invalid grouped property access</source>
        <translation>Błędny dostęp do zgrupowanej właściwości</translation>
    </message>
    <message>
        <source>Cannot assign to non-existent default property</source>
        <translation>Nie można przypisać wartości do nieistniejącej domyślnej właściwości</translation>
    </message>
    <message>
        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
        <translation>Nie można przypisać wartości do nieistniejącej właściwości &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Cannot assign primitives to lists</source>
        <translation>Nie można przypisać elementu do listy</translation>
    </message>
    <message>
        <source>Invalid property assignment: unknown enumeration</source>
        <translation>Niepoprawne przypisanie wartości: nieznana wartość wyliczeniowa</translation>
    </message>
    <message>
        <source>Invalid property assignment: string expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano ciągu</translation>
    </message>
    <message>
        <source>Invalid property assignment: string or string list expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano ciągu lub listy ciągów</translation>
    </message>
    <message>
        <source>Invalid property assignment: byte array expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano tablicy bajtowej</translation>
    </message>
    <message>
        <source>Invalid property assignment: url expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano url</translation>
    </message>
    <message>
        <source>Invalid property assignment: unsigned int expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano liczby naturalnej</translation>
    </message>
    <message>
        <source>Invalid property assignment: int expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano liczby całkowitej</translation>
    </message>
    <message>
        <source>Invalid property assignment: number expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano liczby</translation>
    </message>
    <message>
        <source>Invalid property assignment: color expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano koloru</translation>
    </message>
    <message>
        <source>Invalid property assignment: date expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano daty</translation>
    </message>
    <message>
        <source>Invalid property assignment: time expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano czasu</translation>
    </message>
    <message>
        <source>Invalid property assignment: datetime expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano daty i czasu</translation>
    </message>
    <message>
        <source>Invalid property assignment: point expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano punktu</translation>
    </message>
    <message>
        <source>Invalid property assignment: size expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano rozmiaru</translation>
    </message>
    <message>
        <source>Invalid property assignment: rect expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano prostokąta</translation>
    </message>
    <message>
        <source>Invalid property assignment: boolean expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano wartości boolowskiej</translation>
    </message>
    <message>
        <source>Invalid property assignment: 3D vector expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano wektora 3D</translation>
    </message>
    <message>
        <source>Invalid property assignment: 4D vector expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano wektora 3D</translation>
    </message>
    <message>
        <source>Invalid property assignment: regular expression expected; use /pattern/ syntax</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano wyrażenia regularnego, użyj składni wzorca</translation>
    </message>
    <message>
        <source>Invalid property assignment: number or array of numbers expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano liczby lub tablicy liczb</translation>
    </message>
    <message>
        <source>Invalid property assignment: int or array of ints expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano liczby całkowitej lub tablicy liczb całkowitych</translation>
    </message>
    <message>
        <source>Invalid property assignment: bool or array of bools expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano wartości boolowskiej lub tablicy wartości boolowskich</translation>
    </message>
    <message>
        <source>Invalid property assignment: url or array of urls expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano url lub tablicy url</translation>
    </message>
    <message>
        <source>Invalid property assignment: string or array of strings expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano ciągu lub tablicy ciągów</translation>
    </message>
    <message>
        <source>Invalid property assignment: unsupported type &quot;%1&quot;</source>
        <translation>Niepoprawne przypisanie wartości: nieobsługiwany typ &quot;%1&quot;</translation>
    </message>
    <message>
        <source>&quot;%1&quot; cannot operate on &quot;%2&quot;</source>
        <translation>&quot;%1&quot; nie może operować na &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Cannot assign object to list property &quot;%1&quot;</source>
        <translation>Nie można przypisać obiektu do właściwości typu lista &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Unexpected object assignment</source>
        <translation>Nieoczekiwane przypisanie obiektu</translation>
    </message>
    <message>
        <source>Invalid property assignment: script expected</source>
        <translation>Niepoprawne przypisanie wartości: oczekiwano skryptu</translation>
    </message>
    <message>
        <source>Cannot assign object to property</source>
        <translation>Nie można przypisać obiektu dla właściwości</translation>
    </message>
</context>
<context>
    <name>QQmlRewrite</name>
    <message>
        <source>Signal uses unnamed parameter followed by named parameter.</source>
        <translation>Sygnał używa nienazwanego parametru po którym następuje nazwany parametr.</translation>
    </message>
    <message>
        <source>Signal parameter &quot;%1&quot; hides global variable.</source>
        <translation>Parametr sygnału &quot;%1&quot; przykrywa globalną zmienną.</translation>
    </message>
</context>
<context>
    <name>QQmlTypeCompiler</name>
    <message>
        <source>Composite Singleton Type %1 is not creatable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Element is not creatable.</source>
        <translation>Nie można utworzyć elementu (&quot;creatable&quot; wyłączone).</translation>
    </message>
</context>
<context>
    <name>QQmlTypeLoader</name>
    <message>
        <source>Cannot update qmldir content for &apos;%1&apos;</source>
        <translation>Nie można odświeżyć zawartości qmldir dla &quot;%1&quot;</translation>
    </message>
    <message>
        <source>No matching type found, pragma Singleton files cannot be used by QQmlComponent.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pragma Singleton used with a non composite singleton type %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Script %1 unavailable</source>
        <translation>Skrypt &quot;%1&quot; nie jest dostępny</translation>
    </message>
    <message>
        <source>Type %1 unavailable</source>
        <translation>Typ %1 nie jest dostępny</translation>
    </message>
    <message>
        <source>qmldir defines type as singleton, but no pragma Singleton found in type %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>module &quot;%1&quot; is not installed</source>
        <translation>moduł &quot;%1&quot; nie jest zainstalowany</translation>
    </message>
    <message>
        <source>Namespace %1 cannot be used as a type</source>
        <translation>Przestrzeń nazw %1 nie może być użyta jako typ</translation>
    </message>
    <message>
        <source>Unreported error adding script import to import database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 %2</source>
        <translation>%1 %2</translation>
    </message>
</context>
<context>
    <name>QQuickAbstractAnimation</name>
    <message>
        <source>Cannot animate non-existent property &quot;%1&quot;</source>
        <translation>Nie można animować nieistniejącej właściwości &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Cannot animate read-only property &quot;%1&quot;</source>
        <translation>Nie można animować właściwości (tylko do odczytu): &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Animation is an abstract class</source>
        <translation>&quot;Animation&quot; jest klasą abstrakcyjną</translation>
    </message>
    <message>
        <source>Animator is an abstract class</source>
        <translation>&quot;Animator&quot; jest klasą abstrakcyjną</translation>
    </message>
</context>
<context>
    <name>QQuickAccessibleAttached</name>
    <message>
        <source>Accessible is only available via attached properties</source>
        <translation>&quot;Accessible&quot; jest dostępny jedynie poprzez dołączone właściwości</translation>
    </message>
</context>
<context>
    <name>QQuickAnchorAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>Nie można ustawić ujemnego czasu trwania</translation>
    </message>
</context>
<context>
    <name>QQuickAnchors</name>
    <message>
        <source>Possible anchor loop detected on fill.</source>
        <translation>Wykryto możliwe zapętlenie dla kotwicy &quot;fill&quot;.</translation>
    </message>
    <message>
        <source>Possible anchor loop detected on centerIn.</source>
        <translation>Wykryto możliwe zapętlenie dla kotwicy &quot;centerIn&quot;.</translation>
    </message>
    <message>
        <source>Cannot anchor to an item that isn&apos;t a parent or sibling.</source>
        <translation>Nie można doczepić kotwicy do elementu który nie jest rodzicem ani rodzeństwem.</translation>
    </message>
    <message>
        <source>Possible anchor loop detected on vertical anchor.</source>
        <translation>Wykryto możliwe zapętlenie dla pionowej kotwicy.</translation>
    </message>
    <message>
        <source>Possible anchor loop detected on horizontal anchor.</source>
        <translation>Wykryto możliwe zapętlenie dla poziomej kotwicy.</translation>
    </message>
    <message>
        <source>Cannot specify left, right, and horizontalCenter anchors at the same time.</source>
        <translation>Nie można jednocześnie zdefiniować kotwicy lewej, prawej i wyśrodkowanej w poziomie.</translation>
    </message>
    <message>
        <source>Cannot anchor to a null item.</source>
        <translation>Nie można doczepić kotwicy do zerowego elementu.</translation>
    </message>
    <message>
        <source>Cannot anchor a horizontal edge to a vertical edge.</source>
        <translation>Nie można doczepić poziomej krawędzi do pionowej.</translation>
    </message>
    <message>
        <source>Cannot anchor item to self.</source>
        <translation>Nie można doczepić kotwicy elementu do tego samego elementu.</translation>
    </message>
    <message>
        <source>Cannot specify top, bottom, and verticalCenter anchors at the same time.</source>
        <translation>Nie można jednocześnie zdefiniować kotwicy górnej, dolnej i wyśrodkowanej w pionie.</translation>
    </message>
    <message>
        <source>Baseline anchor cannot be used in conjunction with top, bottom, or verticalCenter anchors.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot anchor a vertical edge to a horizontal edge.</source>
        <translation>Nie można doczepić pionowej krawędzi do poziomej.</translation>
    </message>
</context>
<context>
    <name>QQuickAnimatedImage</name>
    <message>
        <source>Qt was built without support for QMovie</source>
        <translation>Qt zostało zbudowane bez obsługi QMovie</translation>
    </message>
</context>
<context>
    <name>QQuickApplication</name>
    <message>
        <source>Application is an abstract class</source>
        <translation>&quot;Application&quot; jest klasą abstrakcyjną</translation>
    </message>
</context>
<context>
    <name>QQuickBehavior</name>
    <message>
        <source>Cannot change the animation assigned to a Behavior.</source>
        <translation>Nie można zmienić animacji przypisanej do &quot;Behavior&quot;.</translation>
    </message>
</context>
<context>
    <name>QQuickDragAttached</name>
    <message>
        <source>Drag is only available via attached properties</source>
        <translation>&quot;Drag&quot; jest dostępny jedynie poprzez dołączone właściwości</translation>
    </message>
</context>
<context>
    <name>QQuickEnterKeyAttached</name>
    <message>
        <source>EnterKey attached property only works with Items</source>
        <translation>Dołączona właściwość &quot;EnterKey&quot; działa tylko z &quot;Item&quot;</translation>
    </message>
    <message>
        <source>EnterKey is only available via attached properties</source>
        <translation>&quot;EnterKeys&quot; jest dostępny jedynie poprzez dołączone właściwości</translation>
    </message>
</context>
<context>
    <name>QQuickFlipable</name>
    <message>
        <source>front is a write-once property</source>
        <translation>&quot;front&quot; jest właściwością tylko do odczytu</translation>
    </message>
    <message>
        <source>back is a write-once property</source>
        <translation>&quot;back&quot; jest właściwością tylko do odczytu</translation>
    </message>
</context>
<context>
    <name>QQuickItemView</name>
    <message>
        <source>ItemView is an abstract base class</source>
        <translation>&quot;ItemView&quot; jest klasą abstrakcyjną</translation>
    </message>
    <message>
        <source>Delegate must be of Item type</source>
        <translation>&quot;Delegate&quot; musi być typu &quot;Item&quot;</translation>
    </message>
</context>
<context>
    <name>QQuickKeyNavigationAttached</name>
    <message>
        <source>KeyNavigation is only available via attached properties</source>
        <translation>&quot;KeyNavigation&quot; jest dostępny jedynie poprzez dołączone właściwości</translation>
    </message>
</context>
<context>
    <name>QQuickKeysAttached</name>
    <message>
        <source>Keys is only available via attached properties</source>
        <translation>&quot;Keys&quot; jest dostępny jedynie poprzez dołączone właściwości</translation>
    </message>
</context>
<context>
    <name>QQuickLayoutMirroringAttached</name>
    <message>
        <source>LayoutDirection attached property only works with Items</source>
        <translation>Dołączona właściwość &quot;LayoutDirection&quot; działa tylko z &quot;Item&quot;</translation>
    </message>
    <message>
        <source>LayoutMirroring is only available via attached properties</source>
        <translation>&quot;LayoutMirroring&quot; dostępny jest tylko poprzez dołączone właściwości</translation>
    </message>
</context>
<context>
    <name>QQuickLoader</name>
    <message>
        <source>setSource: value is not an object</source>
        <translation>setSource: wartość nie jest obiektem</translation>
    </message>
</context>
<context>
    <name>QQuickMouseEvent</name>
    <message>
        <source>MouseEvent is only available within handlers in MouseArea</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QQuickOpenGLInfo</name>
    <message>
        <source>OpenGLInfo is only available via attached properties</source>
        <translation>&quot;OpenGLInfo&quot; jest dostępny jedynie poprzez dołączone właściwości</translation>
    </message>
</context>
<context>
    <name>QQuickPaintedItem</name>
    <message>
        <source>Cannot create instance of abstract class PaintedItem</source>
        <translation>Nie można utworzyć obiektu abstrakcyjnej klasy &quot;PaintedItem&quot;</translation>
    </message>
</context>
<context>
    <name>QQuickParentAnimation</name>
    <message>
        <source>Unable to preserve appearance under complex transform</source>
        <translation>Nie można utrzymać wyglądu przy złożonej transformacji</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under non-uniform scale</source>
        <translation>Nie można utrzymać wyglądu przy niejednolitej skali</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under scale of 0</source>
        <translation>Nie można utrzymać wyglądu przy zerowej skali</translation>
    </message>
</context>
<context>
    <name>QQuickParentChange</name>
    <message>
        <source>Unable to preserve appearance under complex transform</source>
        <translation>Nie można utrzymać wyglądu przy złożonej transformacji</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under non-uniform scale</source>
        <translation>Nie można utrzymać wyglądu przy niejednolitej skali</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under scale of 0</source>
        <translation>Nie można utrzymać wyglądu przy zerowej skali</translation>
    </message>
</context>
<context>
    <name>QQuickPathAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>Nie można ustawić ujemnego czasu trwania</translation>
    </message>
</context>
<context>
    <name>QQuickPathView</name>
    <message>
        <source>Delegate must be of Item type</source>
        <translation>&quot;Delegate&quot; musi być typu &quot;Item&quot;</translation>
    </message>
</context>
<context>
    <name>QQuickPauseAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>Nie można ustawić ujemnego czasu trwania</translation>
    </message>
</context>
<context>
    <name>QQuickPixmap</name>
    <message>
        <source>Error decoding: %1: %2</source>
        <translation>Błąd dekodowania: %1: %2</translation>
    </message>
    <message>
        <source>Invalid image provider: %1</source>
        <translation>Niepoprawny dostawca obrazów: %1</translation>
    </message>
    <message>
        <source>Failed to get image from provider: %1</source>
        <translation>Pobieranie obrazu od dostawcy zakończone błędem: %1</translation>
    </message>
    <message>
        <source>Failed to get texture from provider: %1</source>
        <translation>Błąd pobierania tekstury od dostawcy: %1</translation>
    </message>
    <message>
        <source>Cannot open: %1</source>
        <translation>Nie można otworzyć: %1</translation>
    </message>
</context>
<context>
    <name>QQuickPropertyAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>Nie można ustawić ujemnego czasu trwania</translation>
    </message>
</context>
<context>
    <name>QQuickPropertyChanges</name>
    <message>
        <source>PropertyChanges does not support creating state-specific objects.</source>
        <translation>&quot;PropertyChanges&quot; nie obsługuje tworzenia obiektów charakterystycznych dla stanów.</translation>
    </message>
    <message>
        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
        <translation>Nie można przypisać wartości do nieistniejącej właściwości &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Cannot assign to read-only property &quot;%1&quot;</source>
        <translation>Nie można przypisać wartości do właściwości (tylko do odczytu): &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>QQuickRepeater</name>
    <message>
        <source>Delegate must be of Item type</source>
        <translation>&quot;Delegate&quot; musi być typu &quot;Item&quot;</translation>
    </message>
</context>
<context>
    <name>QQuickShaderEffectMesh</name>
    <message>
        <source>Cannot create instance of abstract class ShaderEffectMesh.</source>
        <translation>Nie można utworzyć obiektu abstrakcyjnej klasy &quot;ShaderEffectMesh&quot;.</translation>
    </message>
</context>
<context>
    <name>QQuickTextUtil</name>
    <message>
        <source>%1 does not support loading non-visual cursor delegates.</source>
        <translation>%1 nie obsługuje ładowania niewirtualnych delegatów kursora.</translation>
    </message>
    <message>
        <source>Could not load cursor delegate</source>
        <translation>Nie można załadować delegata kursora</translation>
    </message>
</context>
<context>
    <name>QQuickViewTransitionAttached</name>
    <message>
        <source>ViewTransition is only available via attached properties</source>
        <translation>&quot;ViewTransition&quot; jest dostępny jedynie poprzez dołączone właściwości</translation>
    </message>
</context>
<context>
    <name>QQuickWindow</name>
    <message>
        <source>Failed to create %1 context for format %2.
This is most likely caused by not having the necessary graphics drivers installed.

Install a driver providing OpenGL 2.0 or higher, or, if this is not possible, make sure the ANGLE Open GL ES 2.0 emulation libraries (%3, %4 and d3dcompiler_*.dll) are available in the application executable&apos;s directory or in a location listed in PATH.</source>
        <extracomment>%1 Context type (Open GL, EGL), %2 format, ANGLE %3, %4 library names</extracomment>
        <translation>Błąd tworzenia kontekstu %1 w formacie %2.
Najprawdopodobniej jest to spowodowane brakiem wymaganych sterowników graficznych.

Zainstaluj sterownik obsługujący OpenGL w wersji 2.0 lub wyższej, lub jeśli to niemożliwe upewnij się, że biblioteki emulatora ANGLE Open GL ES 2.0 (%3, %4 i d3dcompiler_*.dll) są dostępne w katalogu z plikiem wykonywalnym aplikacji lub w jednej ze ścieżek wymienionych w PATH.</translation>
    </message>
    <message>
        <source>Failed to create %1 context for format %2</source>
        <extracomment>%1 Context type (Open GL, EGL), %2 format specification</extracomment>
        <translation>Nie można utworzyć kontekstu %1 dla formatu %2</translation>
    </message>
</context>
<context>
    <name>QQuickWindowQmlImpl</name>
    <message>
        <source>Conflicting properties &apos;visible&apos; and &apos;visibility&apos; for Window &apos;%1&apos;</source>
        <translation>Konflikt pomiędzy właściwościami &quot;visible&quot; i &quot;visibility&quot; w oknie &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Conflicting properties &apos;visible&apos; and &apos;visibility&apos;</source>
        <translation>Konflikt pomiędzy właściwościami &quot;visible&quot; i &quot;visibility&quot;</translation>
    </message>
</context>
<context>
    <name>QQuickXmlListModel</name>
    <message>
        <source>&quot;%1&quot; duplicates a previous role name and will be disabled.</source>
        <translation>&quot;%1&quot; powiela poprzednią nazwę roli i zostanie wyłączone.</translation>
    </message>
    <message>
        <source>invalid query: &quot;%1&quot;</source>
        <translation>Niepoprawne zapytanie: &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>QQuickXmlListModelRole</name>
    <message>
        <source>An XmlRole query must not start with &apos;/&apos;</source>
        <translation>Zapytanie XmlRole nie może rozpoczynać się od &quot;/&quot;</translation>
    </message>
</context>
<context>
    <name>QQuickXmlRoleList</name>
    <message>
        <source>An XmlListModel query must start with &apos;/&apos; or &quot;//&quot;</source>
        <translation>Zapytanie XmlListModel nie może rozpoczynać się od &quot;/&quot; ani od &quot;//&quot;</translation>
    </message>
</context>
<context>
    <name>SignalHandlerConverter</name>
    <message>
        <source>Non-existent attached object</source>
        <translation>Dołączony obiekt nie istnieje</translation>
    </message>
    <message>
        <source>Signal uses unnamed parameter followed by named parameter.</source>
        <translation>Sygnał używa nienazwanego parametru po którym następuje nazwany parametr.</translation>
    </message>
    <message>
        <source>Signal parameter &quot;%1&quot; hides global variable.</source>
        <translation>Parametr sygnału &quot;%1&quot; przykrywa globalną zmienną.</translation>
    </message>
    <message>
        <source>&quot;%1.%2&quot; is not available in %3 %4.%5.</source>
        <translation>&quot;%1.%2&quot; nie jest dostępne w %3 %4.%5.</translation>
    </message>
    <message>
        <source>&quot;%1.%2&quot; is not available due to component versioning.</source>
        <translation>&quot;%1.%2&quot; nie jest dostępny z powodu niekompatybilności wersji komponentu.</translation>
    </message>
    <message>
        <source>Cannot assign a value to a signal (expecting a script to be run)</source>
        <translation>Nie można przypisać wartości do sygnału (oczekiwano uruchomienia skryptu)</translation>
    </message>
    <message>
        <source>Incorrectly specified signal assignment</source>
        <translation>Przypisanie sygnału błędnie podane</translation>
    </message>
</context>
<context>
    <name>SignalTransition</name>
    <message>
        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
        <translation>Nie można przypisać wartości do nieistniejącej właściwości &quot;%1&quot;</translation>
    </message>
    <message>
        <source>SignalTransition: script expected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>qmlRegisterType</name>
    <message>
        <source>Invalid QML %1 name &quot;%2&quot;</source>
        <translation>Niepoprawna nazwa %1 QML &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Cannot install %1 &apos;%2&apos; into unregistered namespace &apos;%3&apos;</source>
        <translation>Nie można zainstalować %1 &quot;%2&quot; w niezarejestrowanej przestrzeni nazw &quot;%3&quot;</translation>
    </message>
    <message>
        <source>Cannot install %1 &apos;%2&apos; into protected namespace &apos;%3&apos;</source>
        <translation>Nie można zainstalować %1 &quot;%2&quot; w chronionej przestrzeni nazw &quot;%3&quot;</translation>
    </message>
    <message>
        <source>Cannot install %1 &apos;%2&apos; into protected module &apos;%3&apos; version &apos;%4&apos;</source>
        <translation>Nie można zainstalować %1 &quot;%2&quot; w chronionym module &quot;%3&quot; wersji &quot;%4&quot;</translation>
    </message>
</context>
</TS>
